@@ -69,23 +69,30 @@ class Account:
             return True
         return False
 
-    async def get_questions(self, session) -> None:
+    # Returns if the account has security questions
+    async def get_questions(self, session) -> bool:
         resp, _, resp_json = await session.get(
             "https://api.mojang.com/user/security/challenges", headers=self.headers
         )
 
         self.answer_ids = [question["answer"]["id"] for question in resp_json]
-        self.questions = [question["question"]["question"] for question in resp_json]
+        self.questions = [
+            question["question"]["question"] for question in resp_json
+        ]
 
         if resp.status == 200:
-            return
-        log.error(f"failed to get security questions for {self.email}")
+            return len(self.questions) > 0
 
-    async def need_sqs(self, session) -> bool:
+        if self.is_submit_needed:
+            log.error(f"failed to get security questions for {self.email}")
+
+    async def need_to_submit_sqs(self, session) -> bool:
         resp, _, _ = await session.get(
             "https://api.mojang.com/user/security/location", headers=self.headers
         )
 
+        self.is_submit_needed = resp.status == 403
+
         return resp.status == 403
 
     async def submit_questions(self, session):
@@ -116,21 +123,32 @@ class Account:
             log.error(f"failed to auth {self.email}")
             return
 
-        if not await self.need_sqs(session):
+        if not await self.need_to_submit_sqs(session):
             log.info(
                 f"{color.white}[{color.l_green}success{color.white}]"
                 f"{color.reset} authenticated {self.email}"
             )
         else:
-            await self.get_questions(session)
-            if await self.submit_questions(session):
+            if await self.get_questions(session):
+                if self.is_submit_needed:
+                    if await self.submit_questions(session):
+                        log.info(
+                            f"{color.white}[{color.l_green}success{color.white}]"
+                            f"{color.reset} authenticated {self.email}"
+                            " with security questions"
+                        )
+                    else:
+                        log.error(f"failed to authenticate {self.email}")
+                else:
+                    log.info(
+                        f"{color.white}[{color.l_green}success{color.white}]"
+                        f"{color.reset} authenticated {self.email}"
+                    )
+            else:
                 log.info(
                     f"{color.white}[{color.l_green}success{color.white}]"
                     f"{color.reset} authenticated {self.email}"
-                    " with security questions"
                 )
-            else:
-                log.error(f"failed to authenticate {self.email}")
 
     async def change_skin_file(self, variant, skin, session):
         headers = self.headers
@@ -156,6 +174,9 @@ class Account:
     async def change_skin_url(self, variant, skin, session):
         headers = self.headers
         headers["Content-Type"] = "application/json"
+        if "namemc.com/skin" in skin:
+            skin_id = skin.split('/')[-1]
+            skin = f"https://texture.namemc.com/6c/ed/{skin_id}.png"
         post_json = {
             "variant": variant,
             "url": skin
